.. currentmodule:: sqlalchemy.types

.. _types_api:

Base Type API
-------------

.. autoclass:: TypeEngine
   :members:


.. autoclass:: Concatenable
   :members:


.. autoclass:: Indexable
   :members:

.. autoclass:: NullType


.. autoclass:: Variant
   :members: with_variant, __init__
